From ea114727620483755ebecf7b3fe4e7f9d50316e4 Mon Sep 17 00:00:00 2001
From: "darin@chromium.org"
 <darin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>
Date: Mon, 12 Mar 2012 01:11:25 +0000
Subject: Add content/public/browser/resource_dispatcher_host.h

R=jam@chromium.org
TBR=willchan@chromium.org,mirandac@chromium.org,ben@chromium.org
Review URL: https://chromiumcodereview.appspot.com/9648020

git-svn-id: svn://svn.chromium.org/chrome/trunk/src@126089 0039d316-1c4b-4281-b951-d872f2087c98
---
 content/browser/ssl/ssl_error_handler.h | 13 ++++++++-----
 1 file changed, 8 insertions(+), 5 deletions(-)

(limited to 'content/browser/ssl/ssl_error_handler.h')

diff --git a/content/browser/ssl/ssl_error_handler.h b/content/browser/ssl/ssl_error_handler.h
index 848b9d3..eadf89b 100644
--- a/content/browser/ssl/ssl_error_handler.h
+++ b/content/browser/ssl/ssl_error_handler.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -16,9 +16,12 @@
 #include "googleurl/src/gurl.h"
 #include "webkit/glue/resource_type.h"
 
-class ResourceDispatcherHost;
 class SSLCertErrorHandler;
 
+namespace content {
+class ResourceDispatcherHostImpl;
+}
+
 namespace net {
 class URLRequest;
 }  // namespace net
@@ -83,7 +86,7 @@ class SSLErrorHandler : public base::RefCountedThreadSafe<SSLErrorHandler> {
   friend class base::RefCountedThreadSafe<SSLErrorHandler>;
 
   // Construct on the IO thread.
-  SSLErrorHandler(ResourceDispatcherHost* resource_dispatcher_host,
+  SSLErrorHandler(content::ResourceDispatcherHostImpl* host,
                   net::URLRequest* request,
                   ResourceType::Type resource_type);
 
@@ -102,8 +105,8 @@ class SSLErrorHandler : public base::RefCountedThreadSafe<SSLErrorHandler> {
   // Should only be accessed from the IO thread.
   content::GlobalRequestID request_id_;
 
-  // The ResourceDispatcherHost we are associated with.
-  ResourceDispatcherHost* resource_dispatcher_host_;
+  // The ResourceDispatcherHostImpl we are associated with.
+  content::ResourceDispatcherHostImpl* resource_dispatcher_host_;
 
  private:
   // Completes the CancelRequest operation on the IO thread.
-- 
cgit v1.1